@@ -1431,18 +1431,18 @@ class Widget(Gtk.VBox):
 
         # if there are unsaved reports, show save/ignore/cancel dialog
         if self.is_modified():
-            dialog = mobius.ui.message_dialog(mobius.ui.MESSAGE_DIALOG_TYPE_QUESTION)
+            dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_question)
             dialog.text = "Save changes before closing?"
-            dialog.add_button(mobius.ui.BUTTON_YES)
-            dialog.add_button(mobius.ui.BUTTON_NO)
-            dialog.add_button(mobius.ui.BUTTON_CANCEL)
-            dialog.set_default_response(mobius.ui.BUTTON_CANCEL)
+            dialog.add_button(mobius.ui.message_dialog.button_yes)
+            dialog.add_button(mobius.ui.message_dialog.button_no)
+            dialog.add_button(mobius.ui.message_dialog.button_cancel)
+            dialog.set_default_response(mobius.ui.message_dialog.button_cancel)
             rc = dialog.run()
 
-            if rc == mobius.ui.BUTTON_CANCEL:
+            if rc == mobius.ui.message_dialog.button_cancel:
                 return True
 
-            elif rc == mobius.ui.BUTTON_YES:
+            elif rc == mobius.ui.message_dialog.button_yes:
                 pass  # save
 
         # clean-up code
@@ -1608,14 +1608,14 @@ class Widget(Gtk.VBox):
         else:
             item_type = 'report'
 
-        dialog = mobius.ui.message_dialog(mobius.ui.MESSAGE_DIALOG_TYPE_QUESTION)
-        dialog.text = "You are about to remove %s '%s'. Are you sure?" % (item_type, item_id)
-        dialog.add_button(mobius.ui.BUTTON_YES)
-        dialog.add_button(mobius.ui.BUTTON_NO)
-        dialog.set_default_response(mobius.ui.BUTTON_NO)
+        dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_question)
+        dialog.text = f"You are about to remove {item_type} '{item_id}'. Are you sure?"
+        dialog.add_button(mobius.ui.message_dialog.button_yes)
+        dialog.add_button(mobius.ui.message_dialog.button_no)
+        dialog.set_default_response(mobius.ui.message_dialog.button_no)
         rc = dialog.run()
 
-        if rc != mobius.ui.BUTTON_YES:
+        if rc != mobius.ui.message_dialog.button_yes:
             return
 
         # remove report/folder
