@@ -18,12 +18,10 @@
 #include "message_dialog.h"
 #include "ui.h"
 
-namespace mobius
-{
-namespace ui
+namespace mobius::ui
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Constructor from implementation pointer
+//! \brief Constructor
 //! \param t Message type
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 message_dialog::message_dialog (type t)
@@ -31,5 +29,4 @@ message_dialog::message_dialog (type t)
 {
 }
 
-} // namespace ui
-} // namespace mobius
+} // namespace mobius::ui
