@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -42,7 +42,8 @@ encoder_func_base32 (PyObject *, PyObject *args)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_TypeError, e.what ());
+      mobius::py::set_invalid_type_error (e.what ());
+      return nullptr;
     }
 
   // execute C++ function
@@ -50,15 +51,16 @@ encoder_func_base32 (PyObject *, PyObject *args)
 
   try
     {
-      auto s = mobius::py::GIL () (
-                       mobius::encoder::base32 (arg_data)
-               );
+      ret = mobius::py::pystring_from_std_string (
+               mobius::py::GIL () (
+                  mobius::encoder::base32 (arg_data)
+               )
+            );
 
-      ret = mobius::py::pystring_from_std_string (s);
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   // return value
