@@ -21,6 +21,8 @@
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <pymobius.h>
+#include <pydict.h>
+#include <pyset.h>
 #include "evidence.h"
 #include <mobius/exception.inc>
 #include <stdexcept>
@@ -270,6 +272,47 @@ tp_f_set_attribute (model_evidence_o *self, PyObject *args)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>set_attributes</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_set_attributes (model_evidence_o *self, PyObject *args)
+{
+  // Parse input args
+  std::map <std::string, mobius::pod::data> arg_attributes;
+
+  try
+    {
+      arg_attributes = mobius::py::get_arg_as_cpp_map (
+                          args,
+                          0,
+                          mobius::py::pystring_as_std_string,
+                          pymobius_pod_data_from_pyobject
+      );
+    }
+  catch (const std::exception& e)
+    {
+      mobius::py::set_invalid_type_error (e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  try
+    {
+      self->obj->set_attributes (arg_attributes);
+    }
+  catch (const std::exception& e)
+    {
+      mobius::py::set_runtime_error (e.what ());
+      return nullptr;
+    }
+
+  // return None
+  return mobius::py::pynone ();
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>remove_attribute</i> method implementation
 //! \param self Object
@@ -409,6 +452,42 @@ tp_f_set_tag (model_evidence_o *self, PyObject *args)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>set_tag</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_set_tags (model_evidence_o *self, PyObject *args)
+{
+  // Parse input args
+  std::set <std::string> arg_tags;
+
+  try
+    {
+      arg_tags = mobius::py::get_arg_as_cpp_set (args, 0, mobius::py::pystring_as_std_string);
+    }
+  catch (const std::exception& e)
+    {
+      mobius::py::set_invalid_type_error (e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  try
+    {
+      self->obj->set_tags (arg_tags);
+    }
+  catch (const std::exception& e)
+    {
+      mobius::py::set_runtime_error (e.what ());
+      return nullptr;
+    }
+
+  // return None
+  return mobius::py::pynone ();
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>reset_tag</i> method implementation
 //! \param self Object
@@ -496,6 +575,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Set attribute value"
   },
+  {
+    (char *) "set_attributes",
+    (PyCFunction) tp_f_set_attributes,
+    METH_VARARGS,
+    "Set attributes"
+  },
   {
     (char *) "remove_attribute",
     (PyCFunction) tp_f_remove_attribute,
@@ -520,6 +605,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Set tag"
   },
+  {
+    (char *) "set_tags",
+    (PyCFunction) tp_f_set_tags,
+    METH_VARARGS,
+    "Set tags"
+  },
   {
     (char *) "reset_tag",
     (PyCFunction) tp_f_reset_tag,
