@@ -55,7 +55,7 @@ class Ant(object):
     def on_export_data(self, ant):
         self.__count = len(self.__keywords)
 
-        for keyword in self.__keywords:
+        for keyword in set(self.__keywords):
             ant.test_password(keyword)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
