@@ -18,14 +18,15 @@
 import os.path
 
 import mobius
+import pymobius.p2p.ares
+import pymobius.p2p.emule
+import pymobius.p2p.emuletorrent
+import pymobius.p2p.shareaza
+import pymobius.p2p.utorrent
 import pymobius.registry
 import pymobius.registry.main
-from . import ares
-from . import emule
-from . import emuletorrent
+
 from . import model
-from . import shareaza
-from . import utorrent
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Constants
@@ -62,7 +63,7 @@ def set_handled(item, f):
 
     # add to kff file
     case = item.case
-    path = case.create_path(os.path.join('hashset', '%04d-p2p.ignore' % item.uid))
+    path = case.create_path(os.path.join('hashset', f'{item.uid:04d}-p2p.ignore'))
     fp = open(path, 'a')
     fp.write('%s\n' % h.get_hex_digest())
     fp.close()
@@ -154,7 +155,7 @@ class Ant(object):
         # Clear p2p ignored kff, if any
         mobius.core.logf('DBG 2')
         case = self.__item.case
-        path = case.get_path(os.path.join('hashset', '%04d-p2p.ignore' % self.__item.uid))
+        path = case.get_path(os.path.join('hashset', f'{self.__item.uid:04d}-p2p.ignore'))
 
         if os.path.exists(path):
             os.remove(path)
