@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -17,8 +17,10 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <mobius/unittest.h>
 #include <mobius/core/application.h>
+#include <mobius/core/config.h>
+#include <mobius/core/resource.h>
 
-void
+static void
 testcase_application ()
 {
   mobius::unittest test ("mobius::core::application");
@@ -50,16 +52,56 @@ testcase_application ()
   ASSERT_EXCEPTION (test, app.get_config_path ("../usr/lib"), std::invalid_argument);
   ASSERT_EXCEPTION (test, app.get_cache_path ("../usr/lib"), std::invalid_argument);
 
-  // config
-  app.set_config ("unittest", 1);
-  test.ASSERT_TRUE (app.has_config ("unittest"));
-  test.ASSERT_EQUAL (app.get_config_int ("unittest"), 1);
-  test.ASSERT_EQUAL (app.get_config_string ("unittest"), "1");
+  test.end ();
+}
 
-  app.set_config ("unittest", 2);
-  test.ASSERT_TRUE (app.has_config ("unittest"));
-  test.ASSERT_EQUAL (app.get_config_int ("unittest"), 2);
-  test.ASSERT_EQUAL (app.get_config_string ("unittest"), "2");
+static void
+testcase_config ()
+{
+  mobius::unittest test ("mobius::core::config");
+
+  // config
+  mobius::core::set_config ("unittest", 1);
+  test.ASSERT_TRUE (mobius::core::has_config ("unittest"));
+  test.ASSERT_EQUAL (mobius::core::get_config ("unittest"), 1);
+
+  mobius::core::set_config ("unittest", "abc");
+  test.ASSERT_TRUE (mobius::core::has_config ("unittest"));
+  test.ASSERT_EQUAL (mobius::core::get_config ("unittest"), "abc");
+
+  test.ASSERT_FALSE (mobius::core::has_config ("unittest-aaaa"));
+  test.ASSERT_EQUAL (mobius::core::get_config ("unittest-aaaa"), mobius::pod::data ());
+
+  test.end ();
+}
+
+static void
+testcase_resource ()
+{
+  mobius::unittest test ("mobius::core::resource");
+
+  mobius::core::add_resource ("unittest.x", "x var", 5);
+  mobius::core::add_resource ("unittest.y", "y var", std::string ("abc"));
+
+  test.ASSERT_TRUE (mobius::core::has_resource ("unittest.x"));
+  test.ASSERT_TRUE (mobius::core::has_resource ("unittest.y"));
+  test.ASSERT_FALSE (mobius::core::has_resource ("unittest.z"));
+
+  test.ASSERT_EQUAL (mobius::core::get_resource_value <int> ("unittest.x"), 5);
+  test.ASSERT_EQUAL (mobius::core::get_resource_value <std::string> ("unittest.y"), "abc");
+  ASSERT_EXCEPTION (test, mobius::core::get_resource_value <std::string> ("unittest.x"), std::invalid_argument);
+  ASSERT_EXCEPTION (test, mobius::core::get_resource_value <int> ("unittest.z"), std::runtime_error);
+
+  auto resources = mobius::core::get_resources ("unittest");
+  test.ASSERT_EQUAL (resources.size (), 2);
+  
+  mobius::core::remove_resource ("unittest.z");
+  mobius::core::remove_resource ("unittest.x");
+  test.ASSERT_FALSE (mobius::core::has_resource ("unittest.x"));
+  test.ASSERT_TRUE (mobius::core::has_resource ("unittest.y"));
+  
+  resources = mobius::core::get_resources ("unittest");
+  test.ASSERT_EQUAL (resources.size (), 1);
 
   test.end ();
 }
@@ -68,4 +110,6 @@ void
 unittest_core ()
 {
   testcase_application ();
+  testcase_config ();
+  testcase_resource ();
 }
